Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.Tenant) predicate.Tenant
- func CreatedAt(v time.Time) predicate.Tenant
- func CreatedAtEQ(v time.Time) predicate.Tenant
- func CreatedAtGT(v time.Time) predicate.Tenant
- func CreatedAtGTE(v time.Time) predicate.Tenant
- func CreatedAtIn(vs ...time.Time) predicate.Tenant
- func CreatedAtLT(v time.Time) predicate.Tenant
- func CreatedAtLTE(v time.Time) predicate.Tenant
- func CreatedAtNEQ(v time.Time) predicate.Tenant
- func CreatedAtNotIn(vs ...time.Time) predicate.Tenant
- func HasExecutions() predicate.Tenant
- func HasExecutionsWith(preds ...predicate.Execution) predicate.Tenant
- func HasFunctions() predicate.Tenant
- func HasFunctionsWith(preds ...predicate.Function) predicate.Tenant
- func ID(id uuid.UUID) predicate.Tenant
- func IDEQ(id uuid.UUID) predicate.Tenant
- func IDGT(id uuid.UUID) predicate.Tenant
- func IDGTE(id uuid.UUID) predicate.Tenant
- func IDIn(ids ...uuid.UUID) predicate.Tenant
- func IDLT(id uuid.UUID) predicate.Tenant
- func IDLTE(id uuid.UUID) predicate.Tenant
- func IDNEQ(id uuid.UUID) predicate.Tenant
- func IDNotIn(ids ...uuid.UUID) predicate.Tenant
- func MaxConcurrent(v int) predicate.Tenant
- func MaxConcurrentEQ(v int) predicate.Tenant
- func MaxConcurrentGT(v int) predicate.Tenant
- func MaxConcurrentGTE(v int) predicate.Tenant
- func MaxConcurrentIn(vs ...int) predicate.Tenant
- func MaxConcurrentLT(v int) predicate.Tenant
- func MaxConcurrentLTE(v int) predicate.Tenant
- func MaxConcurrentNEQ(v int) predicate.Tenant
- func MaxConcurrentNotIn(vs ...int) predicate.Tenant
- func MaxFunctions(v int) predicate.Tenant
- func MaxFunctionsEQ(v int) predicate.Tenant
- func MaxFunctionsGT(v int) predicate.Tenant
- func MaxFunctionsGTE(v int) predicate.Tenant
- func MaxFunctionsIn(vs ...int) predicate.Tenant
- func MaxFunctionsLT(v int) predicate.Tenant
- func MaxFunctionsLTE(v int) predicate.Tenant
- func MaxFunctionsNEQ(v int) predicate.Tenant
- func MaxFunctionsNotIn(vs ...int) predicate.Tenant
- func MaxMemoryMB(v int) predicate.Tenant
- func MaxMemoryMBEQ(v int) predicate.Tenant
- func MaxMemoryMBGT(v int) predicate.Tenant
- func MaxMemoryMBGTE(v int) predicate.Tenant
- func MaxMemoryMBIn(vs ...int) predicate.Tenant
- func MaxMemoryMBLT(v int) predicate.Tenant
- func MaxMemoryMBLTE(v int) predicate.Tenant
- func MaxMemoryMBNEQ(v int) predicate.Tenant
- func MaxMemoryMBNotIn(vs ...int) predicate.Tenant
- func MaxStorageMB(v int) predicate.Tenant
- func MaxStorageMBEQ(v int) predicate.Tenant
- func MaxStorageMBGT(v int) predicate.Tenant
- func MaxStorageMBGTE(v int) predicate.Tenant
- func MaxStorageMBIn(vs ...int) predicate.Tenant
- func MaxStorageMBLT(v int) predicate.Tenant
- func MaxStorageMBLTE(v int) predicate.Tenant
- func MaxStorageMBNEQ(v int) predicate.Tenant
- func MaxStorageMBNotIn(vs ...int) predicate.Tenant
- func MetadataIsNil() predicate.Tenant
- func MetadataNotNil() predicate.Tenant
- func Name(v string) predicate.Tenant
- func NameContains(v string) predicate.Tenant
- func NameContainsFold(v string) predicate.Tenant
- func NameEQ(v string) predicate.Tenant
- func NameEqualFold(v string) predicate.Tenant
- func NameGT(v string) predicate.Tenant
- func NameGTE(v string) predicate.Tenant
- func NameHasPrefix(v string) predicate.Tenant
- func NameHasSuffix(v string) predicate.Tenant
- func NameIn(vs ...string) predicate.Tenant
- func NameLT(v string) predicate.Tenant
- func NameLTE(v string) predicate.Tenant
- func NameNEQ(v string) predicate.Tenant
- func NameNotIn(vs ...string) predicate.Tenant
- func Namespace(v string) predicate.Tenant
- func NamespaceContains(v string) predicate.Tenant
- func NamespaceContainsFold(v string) predicate.Tenant
- func NamespaceEQ(v string) predicate.Tenant
- func NamespaceEqualFold(v string) predicate.Tenant
- func NamespaceGT(v string) predicate.Tenant
- func NamespaceGTE(v string) predicate.Tenant
- func NamespaceHasPrefix(v string) predicate.Tenant
- func NamespaceHasSuffix(v string) predicate.Tenant
- func NamespaceIn(vs ...string) predicate.Tenant
- func NamespaceLT(v string) predicate.Tenant
- func NamespaceLTE(v string) predicate.Tenant
- func NamespaceNEQ(v string) predicate.Tenant
- func NamespaceNotIn(vs ...string) predicate.Tenant
- func Not(p predicate.Tenant) predicate.Tenant
- func Or(predicates ...predicate.Tenant) predicate.Tenant
- func UpdatedAt(v time.Time) predicate.Tenant
- func UpdatedAtEQ(v time.Time) predicate.Tenant
- func UpdatedAtGT(v time.Time) predicate.Tenant
- func UpdatedAtGTE(v time.Time) predicate.Tenant
- func UpdatedAtIn(vs ...time.Time) predicate.Tenant
- func UpdatedAtLT(v time.Time) predicate.Tenant
- func UpdatedAtLTE(v time.Time) predicate.Tenant
- func UpdatedAtNEQ(v time.Time) predicate.Tenant
- func UpdatedAtNotIn(vs ...time.Time) predicate.Tenant
- func ValidColumn(column string) bool
- type OrderOption
- func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
- func ByExecutions(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByExecutionsCount(opts ...sql.OrderTermOption) OrderOption
- func ByFunctions(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByFunctionsCount(opts ...sql.OrderTermOption) OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func ByMaxConcurrent(opts ...sql.OrderTermOption) OrderOption
- func ByMaxFunctions(opts ...sql.OrderTermOption) OrderOption
- func ByMaxMemoryMB(opts ...sql.OrderTermOption) OrderOption
- func ByMaxStorageMB(opts ...sql.OrderTermOption) OrderOption
- func ByName(opts ...sql.OrderTermOption) OrderOption
- func ByNamespace(opts ...sql.OrderTermOption) OrderOption
- func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
Constants ¶
const ( // Label holds the string label denoting the tenant type in the database. Label = "tenant" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldName holds the string denoting the name field in the database. FieldName = "name" // FieldNamespace holds the string denoting the namespace field in the database. FieldNamespace = "namespace" // FieldMaxFunctions holds the string denoting the max_functions field in the database. FieldMaxFunctions = "max_functions" // FieldMaxConcurrent holds the string denoting the max_concurrent field in the database. FieldMaxConcurrent = "max_concurrent" // FieldMaxMemoryMB holds the string denoting the max_memory_mb field in the database. FieldMaxMemoryMB = "max_memory_mb" // FieldMaxStorageMB holds the string denoting the max_storage_mb field in the database. FieldMaxStorageMB = "max_storage_mb" // FieldMetadata holds the string denoting the metadata field in the database. FieldMetadata = "metadata" // FieldCreatedAt holds the string denoting the created_at field in the database. FieldCreatedAt = "created_at" // FieldUpdatedAt holds the string denoting the updated_at field in the database. FieldUpdatedAt = "updated_at" // EdgeFunctions holds the string denoting the functions edge name in mutations. EdgeFunctions = "functions" // EdgeExecutions holds the string denoting the executions edge name in mutations. EdgeExecutions = "executions" // Table holds the table name of the tenant in the database. Table = "tenants" // FunctionsTable is the table that holds the functions relation/edge. FunctionsTable = "functions" // FunctionsInverseTable is the table name for the Function entity. // It exists in this package in order to avoid circular dependency with the "function" package. FunctionsInverseTable = "functions" // FunctionsColumn is the table column denoting the functions relation/edge. FunctionsColumn = "tenant_id" // ExecutionsTable is the table that holds the executions relation/edge. ExecutionsTable = "executions" // ExecutionsInverseTable is the table name for the Execution entity. // It exists in this package in order to avoid circular dependency with the "execution" package. ExecutionsInverseTable = "executions" // ExecutionsColumn is the table column denoting the executions relation/edge. ExecutionsColumn = "tenant_id" )
Variables ¶
var ( // NameValidator is a validator for the "name" field. It is called by the builders before save. NameValidator func(string) error // NamespaceValidator is a validator for the "namespace" field. It is called by the builders before save. NamespaceValidator func(string) error // DefaultMaxFunctions holds the default value on creation for the "max_functions" field. DefaultMaxFunctions int // MaxFunctionsValidator is a validator for the "max_functions" field. It is called by the builders before save. MaxFunctionsValidator func(int) error // DefaultMaxConcurrent holds the default value on creation for the "max_concurrent" field. DefaultMaxConcurrent int // MaxConcurrentValidator is a validator for the "max_concurrent" field. It is called by the builders before save. MaxConcurrentValidator func(int) error // DefaultMaxMemoryMB holds the default value on creation for the "max_memory_mb" field. DefaultMaxMemoryMB int // MaxMemoryMBValidator is a validator for the "max_memory_mb" field. It is called by the builders before save. MaxMemoryMBValidator func(int) error // DefaultMaxStorageMB holds the default value on creation for the "max_storage_mb" field. DefaultMaxStorageMB int // MaxStorageMBValidator is a validator for the "max_storage_mb" field. It is called by the builders before save. MaxStorageMBValidator func(int) error // DefaultCreatedAt holds the default value on creation for the "created_at" field. DefaultCreatedAt func() time.Time // DefaultUpdatedAt holds the default value on creation for the "updated_at" field. DefaultUpdatedAt func() time.Time // UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field. UpdateDefaultUpdatedAt func() time.Time // DefaultID holds the default value on creation for the "id" field. DefaultID func() uuid.UUID )
var Columns = []string{ FieldID, FieldName, FieldNamespace, FieldMaxFunctions, FieldMaxConcurrent, FieldMaxMemoryMB, FieldMaxStorageMB, FieldMetadata, FieldCreatedAt, FieldUpdatedAt, }
Columns holds all SQL columns for tenant fields.
Functions ¶
func CreatedAt ¶
CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.
func CreatedAtEQ ¶
CreatedAtEQ applies the EQ predicate on the "created_at" field.
func CreatedAtGT ¶
CreatedAtGT applies the GT predicate on the "created_at" field.
func CreatedAtGTE ¶
CreatedAtGTE applies the GTE predicate on the "created_at" field.
func CreatedAtIn ¶
CreatedAtIn applies the In predicate on the "created_at" field.
func CreatedAtLT ¶
CreatedAtLT applies the LT predicate on the "created_at" field.
func CreatedAtLTE ¶
CreatedAtLTE applies the LTE predicate on the "created_at" field.
func CreatedAtNEQ ¶
CreatedAtNEQ applies the NEQ predicate on the "created_at" field.
func CreatedAtNotIn ¶
CreatedAtNotIn applies the NotIn predicate on the "created_at" field.
func HasExecutions ¶
HasExecutions applies the HasEdge predicate on the "executions" edge.
func HasExecutionsWith ¶
HasExecutionsWith applies the HasEdge predicate on the "executions" edge with a given conditions (other predicates).
func HasFunctions ¶
HasFunctions applies the HasEdge predicate on the "functions" edge.
func HasFunctionsWith ¶
HasFunctionsWith applies the HasEdge predicate on the "functions" edge with a given conditions (other predicates).
func MaxConcurrent ¶
MaxConcurrent applies equality check predicate on the "max_concurrent" field. It's identical to MaxConcurrentEQ.
func MaxConcurrentEQ ¶
MaxConcurrentEQ applies the EQ predicate on the "max_concurrent" field.
func MaxConcurrentGT ¶
MaxConcurrentGT applies the GT predicate on the "max_concurrent" field.
func MaxConcurrentGTE ¶
MaxConcurrentGTE applies the GTE predicate on the "max_concurrent" field.
func MaxConcurrentIn ¶
MaxConcurrentIn applies the In predicate on the "max_concurrent" field.
func MaxConcurrentLT ¶
MaxConcurrentLT applies the LT predicate on the "max_concurrent" field.
func MaxConcurrentLTE ¶
MaxConcurrentLTE applies the LTE predicate on the "max_concurrent" field.
func MaxConcurrentNEQ ¶
MaxConcurrentNEQ applies the NEQ predicate on the "max_concurrent" field.
func MaxConcurrentNotIn ¶
MaxConcurrentNotIn applies the NotIn predicate on the "max_concurrent" field.
func MaxFunctions ¶
MaxFunctions applies equality check predicate on the "max_functions" field. It's identical to MaxFunctionsEQ.
func MaxFunctionsEQ ¶
MaxFunctionsEQ applies the EQ predicate on the "max_functions" field.
func MaxFunctionsGT ¶
MaxFunctionsGT applies the GT predicate on the "max_functions" field.
func MaxFunctionsGTE ¶
MaxFunctionsGTE applies the GTE predicate on the "max_functions" field.
func MaxFunctionsIn ¶
MaxFunctionsIn applies the In predicate on the "max_functions" field.
func MaxFunctionsLT ¶
MaxFunctionsLT applies the LT predicate on the "max_functions" field.
func MaxFunctionsLTE ¶
MaxFunctionsLTE applies the LTE predicate on the "max_functions" field.
func MaxFunctionsNEQ ¶
MaxFunctionsNEQ applies the NEQ predicate on the "max_functions" field.
func MaxFunctionsNotIn ¶
MaxFunctionsNotIn applies the NotIn predicate on the "max_functions" field.
func MaxMemoryMB ¶
MaxMemoryMB applies equality check predicate on the "max_memory_mb" field. It's identical to MaxMemoryMBEQ.
func MaxMemoryMBEQ ¶
MaxMemoryMBEQ applies the EQ predicate on the "max_memory_mb" field.
func MaxMemoryMBGT ¶
MaxMemoryMBGT applies the GT predicate on the "max_memory_mb" field.
func MaxMemoryMBGTE ¶
MaxMemoryMBGTE applies the GTE predicate on the "max_memory_mb" field.
func MaxMemoryMBIn ¶
MaxMemoryMBIn applies the In predicate on the "max_memory_mb" field.
func MaxMemoryMBLT ¶
MaxMemoryMBLT applies the LT predicate on the "max_memory_mb" field.
func MaxMemoryMBLTE ¶
MaxMemoryMBLTE applies the LTE predicate on the "max_memory_mb" field.
func MaxMemoryMBNEQ ¶
MaxMemoryMBNEQ applies the NEQ predicate on the "max_memory_mb" field.
func MaxMemoryMBNotIn ¶
MaxMemoryMBNotIn applies the NotIn predicate on the "max_memory_mb" field.
func MaxStorageMB ¶
MaxStorageMB applies equality check predicate on the "max_storage_mb" field. It's identical to MaxStorageMBEQ.
func MaxStorageMBEQ ¶
MaxStorageMBEQ applies the EQ predicate on the "max_storage_mb" field.
func MaxStorageMBGT ¶
MaxStorageMBGT applies the GT predicate on the "max_storage_mb" field.
func MaxStorageMBGTE ¶
MaxStorageMBGTE applies the GTE predicate on the "max_storage_mb" field.
func MaxStorageMBIn ¶
MaxStorageMBIn applies the In predicate on the "max_storage_mb" field.
func MaxStorageMBLT ¶
MaxStorageMBLT applies the LT predicate on the "max_storage_mb" field.
func MaxStorageMBLTE ¶
MaxStorageMBLTE applies the LTE predicate on the "max_storage_mb" field.
func MaxStorageMBNEQ ¶
MaxStorageMBNEQ applies the NEQ predicate on the "max_storage_mb" field.
func MaxStorageMBNotIn ¶
MaxStorageMBNotIn applies the NotIn predicate on the "max_storage_mb" field.
func MetadataIsNil ¶
MetadataIsNil applies the IsNil predicate on the "metadata" field.
func MetadataNotNil ¶
MetadataNotNil applies the NotNil predicate on the "metadata" field.
func NameContains ¶
NameContains applies the Contains predicate on the "name" field.
func NameContainsFold ¶
NameContainsFold applies the ContainsFold predicate on the "name" field.
func NameEqualFold ¶
NameEqualFold applies the EqualFold predicate on the "name" field.
func NameHasPrefix ¶
NameHasPrefix applies the HasPrefix predicate on the "name" field.
func NameHasSuffix ¶
NameHasSuffix applies the HasSuffix predicate on the "name" field.
func Namespace ¶
Namespace applies equality check predicate on the "namespace" field. It's identical to NamespaceEQ.
func NamespaceContains ¶
NamespaceContains applies the Contains predicate on the "namespace" field.
func NamespaceContainsFold ¶
NamespaceContainsFold applies the ContainsFold predicate on the "namespace" field.
func NamespaceEQ ¶
NamespaceEQ applies the EQ predicate on the "namespace" field.
func NamespaceEqualFold ¶
NamespaceEqualFold applies the EqualFold predicate on the "namespace" field.
func NamespaceGT ¶
NamespaceGT applies the GT predicate on the "namespace" field.
func NamespaceGTE ¶
NamespaceGTE applies the GTE predicate on the "namespace" field.
func NamespaceHasPrefix ¶
NamespaceHasPrefix applies the HasPrefix predicate on the "namespace" field.
func NamespaceHasSuffix ¶
NamespaceHasSuffix applies the HasSuffix predicate on the "namespace" field.
func NamespaceIn ¶
NamespaceIn applies the In predicate on the "namespace" field.
func NamespaceLT ¶
NamespaceLT applies the LT predicate on the "namespace" field.
func NamespaceLTE ¶
NamespaceLTE applies the LTE predicate on the "namespace" field.
func NamespaceNEQ ¶
NamespaceNEQ applies the NEQ predicate on the "namespace" field.
func NamespaceNotIn ¶
NamespaceNotIn applies the NotIn predicate on the "namespace" field.
func UpdatedAt ¶
UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.
func UpdatedAtEQ ¶
UpdatedAtEQ applies the EQ predicate on the "updated_at" field.
func UpdatedAtGT ¶
UpdatedAtGT applies the GT predicate on the "updated_at" field.
func UpdatedAtGTE ¶
UpdatedAtGTE applies the GTE predicate on the "updated_at" field.
func UpdatedAtIn ¶
UpdatedAtIn applies the In predicate on the "updated_at" field.
func UpdatedAtLT ¶
UpdatedAtLT applies the LT predicate on the "updated_at" field.
func UpdatedAtLTE ¶
UpdatedAtLTE applies the LTE predicate on the "updated_at" field.
func UpdatedAtNEQ ¶
UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.
func UpdatedAtNotIn ¶
UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the Tenant queries.
func ByCreatedAt ¶
func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
ByCreatedAt orders the results by the created_at field.
func ByExecutions ¶
func ByExecutions(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByExecutions orders the results by executions terms.
func ByExecutionsCount ¶
func ByExecutionsCount(opts ...sql.OrderTermOption) OrderOption
ByExecutionsCount orders the results by executions count.
func ByFunctions ¶
func ByFunctions(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByFunctions orders the results by functions terms.
func ByFunctionsCount ¶
func ByFunctionsCount(opts ...sql.OrderTermOption) OrderOption
ByFunctionsCount orders the results by functions count.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByMaxConcurrent ¶
func ByMaxConcurrent(opts ...sql.OrderTermOption) OrderOption
ByMaxConcurrent orders the results by the max_concurrent field.
func ByMaxFunctions ¶
func ByMaxFunctions(opts ...sql.OrderTermOption) OrderOption
ByMaxFunctions orders the results by the max_functions field.
func ByMaxMemoryMB ¶
func ByMaxMemoryMB(opts ...sql.OrderTermOption) OrderOption
ByMaxMemoryMB orders the results by the max_memory_mb field.
func ByMaxStorageMB ¶
func ByMaxStorageMB(opts ...sql.OrderTermOption) OrderOption
ByMaxStorageMB orders the results by the max_storage_mb field.
func ByName ¶
func ByName(opts ...sql.OrderTermOption) OrderOption
ByName orders the results by the name field.
func ByNamespace ¶
func ByNamespace(opts ...sql.OrderTermOption) OrderOption
ByNamespace orders the results by the namespace field.
func ByUpdatedAt ¶
func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
ByUpdatedAt orders the results by the updated_at field.